export_debug_snapshot

Function export_debug_snapshot 

pub async fn export_debug_snapshot(
    source: &ClientStorage,
    file: impl AsRef<Path>,
    options: DebugSnapshotOptions,
) -> Result<(), Error>
Export a ZIP archive containing a snapshot of an account state; if the file exists it is overwritten.

Privacy

No secret information is included but it does include the account identifier and folder names.